@@ -3,6 +3,7 @@ from os import path, makedirs, getenv
 import openai
 from rich.progress import Console
 import json
+import readline
 
 console = Console()
 
@@ -25,12 +26,13 @@ def configure_openai():
 
 
 @click.group(invoke_without_command=True)
-@click.version_option(version="1.0.3")
-@click.option('--clear', is_flag=True, help='🌊 Clear the context each round of chat')
+@click.version_option(version="1.0.5")
+@click.option("--clear", is_flag=True, help="🌊 Clear the context each round of chat")
 def cli(clear):
-    """ 🥝 A command line application to interact with OpenAI's ChatGPT."""
+    """🥝 A command line application to interact with OpenAI's ChatGPT."""
     configure_openai()
     session_data = []
+    click.echo("")
     click.echo(" 🥝 Session started. Enter 'exit' to end the session.")
     while True:
         user_input = click.prompt("➡ ")
@@ -56,7 +58,9 @@ def cli(clear):
             print("🔒 Authentication Failed. Try with a fresh API key.")
             break
         except Exception:
-            print("❌ Failed to get reply from chatGPT. Please try again with a different prompt or check your api key quota.")
+            print(
+                "❌ Failed to get reply from chatGPT. Please try again with a different prompt or check your api key quota."
+            )
             break
 
 
